@@ -273,7 +273,7 @@ def analysis (project, genome, contexts, simContext, input_path, output_type='al
 	chromLengths = {}
 	binsDensity = []
 	if correction or subClassify:
-		chroms = [x.split(".")[0] for x in os.listdir(chrom_path) if x != ".DS_Store" and x[0]!= "G" and x[0] != "M" and x != "BED_" + genome + "_proportions.txt"]
+		chroms = [x.split(".")[0] for x in os.listdir(chrom_path) if x != ".DS_Store" and x[0]!= "G" and x[0] != "M" and x != "BED_" + genome + "_proportions.txt" and x[0] != 'm']
 		chroms = sorted(chroms, key = lambda x: ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22','X','Y'].index(x[0:]))
 		chromLengths[genome] = {}
 		totalLength = 0
@@ -315,7 +315,9 @@ def analysis (project, genome, contexts, simContext, input_path, output_type='al
 	output_path = ref_dir + "output/vcf_files" + path_suffix + "/single/"
 	if os.path.exists(output_path) or output_type != None:
 		#if sortSims:
-		os.system("rm -r " + output_path)
+		if os.path.exists(output_path):
+			shutil.rmtree(output_path)
+		# os.system("rm -r " + output_path)
 	os.makedirs(output_path)
 	output_log_path = ref_dir + "logs/"
 	if not os.path.exists(output_log_path):
