@@ -53,7 +53,7 @@ def pullVaf (project, project_path, sanger=True, TCGA=False, correction=True):
 					try:
 						vaf = float(lines[-1].split(":")[-1])
 					except:
-						print("There does not seem to be VAF scores in this Sanger-produced file.")
+						print("There does not seem to be VAF scores in this Sanger-produced file.\n\t", vcfFile)
 						break
 					keyLine = ":".join([chrom, pos, ref, alt])
 					vafs[sample][keyLine] = vaf
