@@ -1088,7 +1088,7 @@ def rainfall (chrom_based_IMD, project, project_path, chrom_path, correction=Tru
 	if len(mutationsPath) > 1:
 		for i in range(1, len(mutationsPath), 1):
 			if classes[i] == "Class III":
-				newMutations = pd.read_csv(mutationsPath[i], sep="\t", names=headerFields, header=0, skiprows=[0],)
+				newMutations = pd.read_csv(mutationsPath[i], sep="\t", names=headerFields, header=0)#, skiprows=[0],)
 			elif classes[i] == "Non-clust":
 				newMutations = pd.read_csv(mutationsPath[i], sep="\t", names=["project", "samples","ID","genome","mutType","chr","start","end", "ref", "alt", "mutClass", "IMD"], header=0, skiprows=[0], engine='python')
 			else:
@@ -1102,7 +1102,7 @@ def rainfall (chrom_based_IMD, project, project_path, chrom_path, correction=Tru
 
 	# Set up chromosome parameters:
 	# chrom_path = "/anaconda3/lib/python3.6/site-packages/SigProfilerMatrixGenerator/references/chromosomes/tsb/" + genome + "/"
-	chroms = [x.split(".")[0] for x in os.listdir(chrom_path) if x != ".DS_Store" and x[0]!= "G" and x[0] != "M" and x != "BED_" + genome + "_proportions.txt"]
+	chroms = [x.split(".")[0] for x in os.listdir(chrom_path) if x != ".DS_Store" and x[0]!= "G" and x[0] != "M" and x != "BED_" + genome + "_proportions.txt" and 'proportions' not in x]
 	chroms = sorted(chroms, key = lambda x: ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22','X','Y'].index(x[0:]))
 	pp = PdfPages(outputPath + "rainfallPlots_clustered_" + plot_suffix +".pdf")
 	colors = ['red',  'orange','black', 'green',  'blue', 'grey']
@@ -1116,7 +1116,7 @@ def rainfall (chrom_based_IMD, project, project_path, chrom_path, correction=Tru
 
 	if correction:
 		chromLengths2 = {}
-		chroms = [x.split(".")[0] for x in os.listdir(chrom_path) if x != ".DS_Store" and x[0]!= "G" and x[0] != "M" and x != "BED_" + genome + "_proportions.txt"]
+		chroms = [x.split(".")[0] for x in os.listdir(chrom_path) if x != ".DS_Store" and x[0]!= "G" and x[0] != "M" and x != "BED_" + genome + "_proportions.txt" and 'proportions' not in x]
 		chroms = sorted(chroms, key = lambda x: ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22','X','Y'].index(x[0:]))
 		chromLengths2[genome] = {}
 		totalLength = 0
